extends Node2D

const CREDITS_SCENE := "res://credits/Credits.tscn"
const HAPPY_ENDING_SCENE := "res://endings/HappyEnding.tscn"

onready var _overlay_animation_player := $OverlayAnimationPlayer
onready var _current_customer := $Snah
onready var _drink := $Drink
onready var _dialogue_interface := $UI/DialogueInterface
onready var _counter_interface := $UI/CounterInterface

var _customer_state_machine:CustomerStateMachine

func _ready():
	_customer_state_machine = _current_customer.state_machine
	DialogueSingleton.customer_state_machine = _customer_state_machine
	_overlay_animation_player.play("new_client")
	yield(_overlay_animation_player, "animation_finished")
	play()

func next():
	_customer_state_machine.next()
	play()

func play() -> void:
	if Drinks.current_drink:
		_drink.texture = Drinks.current_drink.drink_image
	match(_customer_state_machine.state):
		CustomerStateMachine.STATES.DIALOGUE:
			_dialogue_interface.format_dictionary = \
					_customer_state_machine.format_dictionary
			_dialogue_interface \
					.start_dialogue(_customer_state_machine.current_dialogue)
		CustomerStateMachine.STATES.DRINK:
			_counter_interface.open()
		CustomerStateMachine.STATES.CREDITS:
			_overlay_animation_player.play("client_leaves")
			yield(_overlay_animation_player, "animation_finished")
			get_tree().change_scene(CREDITS_SCENE)
		CustomerStateMachine.STATES.HAPPY_ENDING:
			_overlay_animation_player.play("client_leaves")
			yield(_overlay_animation_player, "animation_finished")
			get_tree().change_scene(HAPPY_ENDING_SCENE)
