class_name CustomerStateMachine
extends Node

signal alcohol_level_updated

enum STATES {
	DIALOGUE,
	DRINK,
	CREDITS,
	HAPPY_ENDING,
}

var state:int = STATES.DIALOGUE
var current_dialogue:String
var current_drink:Drink
var favorability := 0
var format_dictionary := {}
var alcohol_limit:int
var alcohol_level := 0

var _dialogue_index := 0
var _drink_index := 0

var _drinks:Array
var _dialogues:Array
var _failure_dialogues:Array
var _end_dialogue:String
var _drinks_dialogue:String

func _init(_alcohol_limit:int, drinks:Array, dialogues:Array, \
		failure_dialogues:Array, drinks_dialogue:String, end_dialogue:String):
	alcohol_limit = _alcohol_limit
	_drinks = drinks
	_dialogues = dialogues
	_failure_dialogues = failure_dialogues
	_drinks_dialogue = drinks_dialogue
	_end_dialogue = end_dialogue
	
	assert(_dialogues.size() == _drinks.size() + 1)
	assert(_failure_dialogues.size() == _drinks.size())
	
	current_dialogue = _dialogues[_dialogue_index]
	current_drink = Drinks.get_drink_from_key(_drinks[_drink_index])

func next():
	match(state):
		STATES.DIALOGUE:
			if _dialogue_index >= _dialogues.size() \
					and favorability >= 0:
				state = STATES.HAPPY_ENDING
			elif _dialogue_index >= _dialogues.size() \
					or _failure_dialogues.has(current_dialogue):
				state = STATES.CREDITS
			elif _dialogue_index == _dialogues.size() - 1:
				current_dialogue = _end_dialogue
				_dialogue_index += 1
			elif current_dialogue == _drinks_dialogue \
					and Drinks.is_current_drink_correct(current_drink):
				_dialogue_index += 1
				current_dialogue = _dialogues[_dialogue_index]
				_drink_index += 1
				if _drink_index < _drinks.size():
					current_drink = \
							Drinks.get_drink_from_key(_drinks[_drink_index])
			else:
				state = STATES.DRINK
		STATES.DRINK:
			alcohol_level += Drinks.get_alcohol_level()
			emit_signal("alcohol_level_updated")
			if alcohol_level >= alcohol_limit:
				current_dialogue = _failure_dialogues[_drink_index]
			else:
				format_dictionary["ingredient"] = \
						Drinks.get_correct_ingredient(current_drink)
				current_dialogue = _drinks_dialogue
			state = STATES.DIALOGUE
