extends Control

const DIALOGUE_OPTION_SCENE := preload("res://dialogue/DialogueOption.tscn")

onready var _label := $Textbox/Label
onready var _buttons_background := $ButtonsBackground
onready var _buttons_container := $ButtonsBackground/CenterContainer/ButtonsContainer

var format_dictionary := {}

var _parser := WhiskersParser.new(DialogueSingleton)
var _dialogue_state:Dictionary
var _picking_option = false

func _ready():
	set_process(false)

func start_dialogue(file_path:String) -> void:
	show()
	_parser.format_dictionary = format_dictionary
	var data := _parser.open_whiskers(file_path)
	_dialogue_state = _parser.start_dialogue(data)
	if _dialogue_state.has("text"):
		show_text(_dialogue_state.get("text"))
	elif _dialogue_state.has("options") \
			and _dialogue_state.get("options").size() > 0:
		show_options(_dialogue_state.get("options"))
	set_process(true)

func dialogue_next(option_key:String = "") -> void:
	if option_key.empty() and _dialogue_state.has("options") \
			and _dialogue_state.get("options").size() > 0:
		show_options(_dialogue_state.get("options"))
	else:
		_dialogue_state = _parser.next(option_key)
		if _dialogue_state.has("text"):
			show_text(_dialogue_state.get("text"))

	if _dialogue_state.empty():
		set_process(false)
		hide()

func show_text(text:String) -> void:
	_label.current_text = text

func show_options(options:Array) -> void:
	_picking_option = true
	
	for button in _buttons_container.get_children():
		button.queue_free()
	
	_buttons_background.show()
	for option in options:
		var button:DialogueOption = DIALOGUE_OPTION_SCENE.instance()
		_buttons_container.add_child(button)
		button.config(option["key"], option["text"])
		button.connect("pressed", self, "pick_option", [button])

func pick_option(option:DialogueOption) -> void:
	var key := option.key
	_buttons_background.hide()
	_picking_option = false
	dialogue_next(key)

func _process(_delta:float) -> void:
	if Input.is_action_just_pressed("next") and not _picking_option:
		if _label.finished:
			dialogue_next()
		else:
			_label.finished = true
