extends TextureRect

const MIN_INGREDIENTS := 3

onready var _ingredient_buttons := $Ingredients
onready var _cocktail_shaker_button := $CocktailShaker
onready var _recipes_book_interface := $RecipesBookInterface
onready var _shaking_animation_player := $ShakingAnimationPlayer
onready var _shaking_animation := $ShakingAnimation
onready var _drink_image := $ShakingAnimation/CenterContainer/ShakingBox/Drink
onready var _drink_label := $ShakingAnimation/CenterContainer/ShakingBox/Label
onready var _alert := $Alert

var _drink := []
var _ingredient_sound:AudioStreamPlayer
var _first_time := true
var max_ingredients := 3

func _ready():
	set_process(false)
	_ingredient_sound = AudioStreamPlayer.new()
	add_child(_ingredient_sound)

func open() -> void:
	show()
	if _first_time:
		_recipes_book_interface.open()
		_first_time = false

func finish_drink():
	_cocktail_shaker_button.disabled = true
	var drink := Drinks.get_drink_from_ingredients(_drink)
	_drink = []
	Drinks.current_drink = drink
	_drink_image.texture = drink.drink_image
	var drink_name = "???" if Drinks.is_generic(drink) else drink.drink_name
	_drink_label.text = "You've made %s!" % drink_name
	
	_shaking_animation.show()
	_shaking_animation_player.stop()
	_shaking_animation_player.play("make_drink")
	set_process(true)
	
	for button in _ingredient_buttons.get_children():
				button.disabled = false

func _on_Ingredient_ingredient_added(ingredient:Ingredient):
	if _drink.size() >= max_ingredients:
		_alert.alert("You can't add more than %d ingredients." \
				% max_ingredients)
	else:
		_ingredient_sound.stream = ingredient.ingredient_sound
		_ingredient_sound.play()
		_drink.append(ingredient.ingredient_key)
		_ingredient_buttons.get_node(ingredient.ingredient_key).disabled = true

func _on_CocktailShaker_pressed():
	if _drink.size() >= MIN_INGREDIENTS:
		finish_drink()
	else:
		_alert.alert("You need %d more ingredients to create a drink." \
				% (MIN_INGREDIENTS - _drink.size()))

func _process(_delta:float) -> void:
	if Input.is_action_just_pressed("next") \
			and not _shaking_animation_player.is_playing():
		_cocktail_shaker_button.disabled = false
		hide()
		_shaking_animation.hide()
		set_process(false)

func _on_RecipesBook_pressed():
	_recipes_book_interface.open()
