extends Node

const DRINKS_FILE := "res://drinks/drinks.json"

var current_drink:Drink

var _drinks:Array
var _generic_drink:Drink

func _ready():
	reset()

func _is_recipe_fulfilled(recipe:Array, ingredients:Array) -> bool:
	if recipe.size() != ingredients.size():
		return false
	
	for i in ingredients:
		if not recipe.has(i):
			return false
	
	return true

func get_drink_from_ingredients(ingredients:Array) -> Drink:
	for drink in _drinks:
		var recipe:Array = drink.drink_ingredients
		if _is_recipe_fulfilled(recipe, ingredients):
			drink.drink_known = true
			return drink
	
	var drink := _generic_drink
	drink.drink_ingredients = ingredients
	return drink

func get_drink_from_key(drink_key:String) -> Drink:
	for drink in _drinks:
		if drink.drink_key == drink_key:
			return drink
	return null

func get_known_drinks() -> Array:
	var known_drinks = []
	for drink in _drinks:
		if drink.drink_known:
			known_drinks.append(drink)
	return known_drinks

func is_generic(drink:Drink) -> bool:
	return drink.drink_key == _generic_drink.drink_key

func is_current_drink_correct(recipe:Drink) -> bool:
	return not is_generic(recipe) \
			and recipe.drink_key == current_drink.drink_key

func get_correct_ingredient(recipe:Drink) -> String:
	for ingredient in recipe.drink_ingredients:
		if current_drink.drink_ingredients.has(ingredient):
			return ingredient
	return ""

func has_correct_ingredient(recipe:Drink) -> bool:
	return get_correct_ingredient(recipe).length() > 0

func get_alcohol_level() -> int:
	var level := 0
	for ingredient_key in current_drink.drink_ingredients:
		var ingredient := Ingredients.get_ingredient(ingredient_key)
		if ingredient.ingredient_alcoholic:
			level += 1
	return level

func reset() -> void:
	var file := File.new()
	
	var error := file.open(DRINKS_FILE, File.READ)
	assert(not error, "Error reading drinks file")
	
	var data:Dictionary = parse_json(file.get_as_text())
	file.close()
	
	var generic_drink_data:Dictionary = data["generic_drink"]
	_generic_drink = Drink.new(generic_drink_data["key"], \
			generic_drink_data["name"], generic_drink_data["image"])
	
	_drinks = []
	var drinks_data = data["drinks"]
	for drink_data in drinks_data:
		_drinks.append(Drink.new(drink_data["key"], drink_data["name"], \
				drink_data["image"], drink_data["ingredients"], \
				drink_data["known"]))
	current_drink = null
