extends ColorRect

onready var _drink_image := $CenterContainer/Background/DrinkImage
onready var _drink_name := $CenterContainer/Background/DrinkName
onready var _ingredients := $CenterContainer/Background/Ingredients
onready var _left_button := $CenterContainer/Background/LeftButton
onready var _right_button := $CenterContainer/Background/RightButton
onready var _page_flip := $PageFlip

var _mouse_outside := true
var _current_drink := 0
var _known_drinks := []

func _ready():
	set_process(false)

func open():
	_current_drink = 0
	_known_drinks = Drinks.get_known_drinks()
	update_drink()
	_page_flip.play()
	show()
	set_process(true)

func update_drink():
	_left_button.visible = _current_drink > 0
	_right_button.visible = _current_drink < _known_drinks.size() - 1
	
	var drink = _known_drinks[_current_drink]
	_drink_image.texture = drink.drink_image
	_drink_name.text = drink.drink_name
	
	var ingredients_text = ""
	for key in drink.drink_ingredients:
		ingredients_text += Ingredients.get_ingredient(key).ingredient_name \
				+ "\n\n"
	_ingredients.text = ingredients_text

func _process(_delta:float) -> void:
	if (Input.is_mouse_button_pressed(BUTTON_LEFT) and _mouse_outside) or \
			Input.is_action_just_pressed("ui_cancel"):
		_page_flip.play()
		hide()
		set_process(false)

func _on_mouse_inside():
	_mouse_outside = false

func _on_mouse_outside():
	_mouse_outside = true

func _on_LeftButton_pressed():
	_current_drink -= 1
	_page_flip.play()
	update_drink()

func _on_RightButton_pressed():
	_current_drink += 1
	_page_flip.play()
	update_drink()
